@@ -104,12 +104,16 @@ class App(cmd2.Cmd):
         elif connect_args.connection_type == 'tcp':
             config_status = tcp_configuration()
 
-        if config_status:
-            status = self.nucleus_driver.connect(connection_type=connect_args.connection_type)
-        else:
-            status = False
+        if not config_status:
+            self.nucleus_driver.messages.write_warning('Failed to set connection configuration')
+            return
 
-        print('Connection status: {}'.format(status))
+        if self.nucleus_driver.connect(connection_type=connect_args.connection_type):
+            self.nucleus_driver.messages.write_message('\r\nSuccessfully connected to Nucleus device\r\n')
+            self.nucleus_driver.messages.write_message('ID:    {}'.format(self.nucleus_driver.connection.nucleus_id))
+            self.nucleus_driver.messages.write_message('GETFW: {}\r\n'.format(self.nucleus_driver.connection.firmware_version))
+        else:
+            self.nucleus_driver.messages.write_warning('\r\nFailed to connect to Nucleus device\r\n')
 
     disconnect_parser = Cmd2ArgumentParser(description='Disconnect from the nucleus device')
 
@@ -117,8 +121,14 @@ class App(cmd2.Cmd):
     @with_category(CMD_CAT_CONNECTING)
     def do_disconnect(self, _):
 
-        status = self.nucleus_driver.disconnect()
-        print('Connection status: {}'.format(not status))
+        if not self.nucleus_driver.connection.get_connection_status():
+            self.nucleus_driver.messages.write_message('No device connected')
+            return
+
+        if self.nucleus_driver.disconnect():
+            self.nucleus_driver.messages.write_message('Disconnected from Nucleus device')
+        else:
+            self.nucleus_driver.messages.write_warning('Failed to disconnect from Nucleus Device')
 
     start_measurement_parser = Cmd2ArgumentParser(description='Start measurement')
 
@@ -206,7 +216,7 @@ class App(cmd2.Cmd):
     ###########################################
     # Assert
     ###########################################
-
+    '''
     set_assert_path_parser = Cmd2ArgumentParser(description='Assert path')
     set_assert_path_parser.add_argument('path', help='Set path for assert file download', completer=cmd2.Cmd.path_complete)
 
@@ -219,18 +229,21 @@ class App(cmd2.Cmd):
         new_path = self.nucleus_driver.set_assert_path(path=path)
 
         self.nucleus_driver.messages.write_message('Assert path is set to: {}'.format(new_path))
-
+    '''
     download_asserts_parser = Cmd2ArgumentParser(description='Download asserts')
+    download_asserts_parser.add_argument('-p', '--path', help='Set path for assert file download', completer=cmd2.Cmd.path_complete)
 
     @with_argparser(download_asserts_parser)
     @with_category(CMD_CAT_ASSERT)
-    def do_assert_download(self, _):
+    def do_assert_download(self, download_asserts_args):
+
+        path = download_asserts_args.path
 
         if not self.nucleus_driver.connection.get_connection_status():
             self.nucleus_driver.messages.write_message('Nucleus not connected')
             return
 
-        if not self.nucleus_driver.assert_download():
+        if not self.nucleus_driver.assert_download(path=path):
             self.nucleus_driver.messages.write_warning('Did not receive any asserts from Nucleus')
 
     clear_asserts_parser = Cmd2ArgumentParser(description='Clear asserts from Nucleus device')
@@ -243,9 +256,7 @@ class App(cmd2.Cmd):
             self.nucleus_driver.messages.write_message('Nucleus not connected')
             return
 
-        response = self.nucleus_driver.clear_assert()
-
-        if b'OK\r\n' in response:
+        if b'OK\r\n' in self.nucleus_driver.clear_assert():
             self.nucleus_driver.messages.write_message('Successfully cleared asserts')
         else:
             self.nucleus_driver.messages.write_warning('Clear assert did not reply with OK: {}'.format(response))
@@ -253,10 +264,10 @@ class App(cmd2.Cmd):
     ##########################################
     # Syslog
     ###########################################
-
+    '''
     set_syslog_path_parser = Cmd2ArgumentParser(description='Syslog path')
     set_syslog_path_parser.add_argument('path', help='Set path for syslog file download', completer=cmd2.Cmd.path_complete)
-
+    
     @with_argparser(set_syslog_path_parser)
     @with_category(CMD_CAT_SYSLOG)
     def do_syslog_set_path(self, set_syslog_path_args):
@@ -266,18 +277,21 @@ class App(cmd2.Cmd):
         new_path = self.nucleus_driver.set_syslog_path(path=path)
 
         self.nucleus_driver.messages.write_message('Syslog path is set to: {}'.format(new_path))
-
+    '''
     download_syslog_parser = Cmd2ArgumentParser(description='Download syslog')
+    download_syslog_parser.add_argument('-p', '--path', help='Set path for syslog file download', completer=cmd2.Cmd.path_complete)
 
     @with_argparser(download_syslog_parser)
     @with_category(CMD_CAT_SYSLOG)
-    def do_syslog_download(self, _):
+    def do_syslog_download(self, download_syslog_args):
+
+        path = download_syslog_args.path
 
         if not self.nucleus_driver.connection.get_connection_status():
             self.nucleus_driver.messages.write_message('Nucleus not connected')
             return
 
-        if not self.nucleus_driver.syslog_download():
+        if not self.nucleus_driver.syslog_download(path=path):
             self.nucleus_driver.messages.write_warning('Did not receive any syslog entries from Nucleus')
 
     clear_syslog_parser = Cmd2ArgumentParser(description='Clear syslog from Nucleus device')
@@ -298,7 +312,7 @@ class App(cmd2.Cmd):
     ##########################################
     # Download
     ###########################################
-
+    '''
     set_download_path_parser = Cmd2ArgumentParser(description='Set download path')
     set_download_path_parser.add_argument('path', help='Select path for download files', completer=cmd2.Cmd.path_complete)
 
@@ -311,11 +325,12 @@ class App(cmd2.Cmd):
         new_path = self.nucleus_driver.set_download_path(path=path)
 
         self.nucleus_driver.messages.write_message('Download path is set to: {}'.format(new_path))
-
+    '''
     download_dvl_parser = Cmd2ArgumentParser(description='Download dvl diagnostics data')
-    download_dvl_parser.add_argument('-fid', help='id of file to download')
-    download_dvl_parser.add_argument('-sa', help='start byte address of file to download')
-    download_dvl_parser.add_argument('-length', help='length of bytes in file to download')
+    download_dvl_parser.add_argument('-f', '--fid', help='id of file to download')
+    download_dvl_parser.add_argument('-s', '--sa', help='start byte address of file to download')
+    download_dvl_parser.add_argument('-l', '--length', help='length of bytes in file to download')
+    download_dvl_parser.add_argument('-p', '--path', help='path for file to be downloaded', completer=cmd2.Cmd.path_complete)
 
     @with_argparser(download_dvl_parser)
     @with_category(CMD_CAT_DOWNLOAD)
@@ -324,6 +339,7 @@ class App(cmd2.Cmd):
         fid = download_dvl_args.fid
         sa = download_dvl_args.sa
         length = download_dvl_args.length
+        path = download_dvl_args.path
 
         if not self.nucleus_driver.connection.get_connection_status():
             self.nucleus_driver.messages.write_message('Nucleus not connected')
@@ -338,7 +354,7 @@ class App(cmd2.Cmd):
         if length is not None:
             length = int(length)
 
-        status = self.nucleus_driver.download_dvl_data(fid=fid, sa=sa, length=length)
+        status = self.nucleus_driver.download_dvl_data(fid=fid, sa=sa, length=length, path=path)
 
         if status:
             self.nucleus_driver.messages.write_message('Successfully downloaded data')
@@ -346,9 +362,10 @@ class App(cmd2.Cmd):
             self.nucleus_driver.messages.write_warning('Failed to completely download data')
 
     download_nucleus_parser = Cmd2ArgumentParser(description='Download nucleus data')
-    download_nucleus_parser.add_argument('-fid', help='id of file to download')
-    download_nucleus_parser.add_argument('-sa', help='start byte address of file to download')
-    download_nucleus_parser.add_argument('-length', help='length of bytes in file to download')
+    download_nucleus_parser.add_argument('-f', '--fid', help='id of file to download')
+    download_nucleus_parser.add_argument('-s', '--sa', help='start byte address of file to download')
+    download_nucleus_parser.add_argument('-l', '--length', help='length of bytes in file to download')
+    download_nucleus_parser.add_argument('-p', '--path', help='path for file to be downloaded', completer=cmd2.Cmd.path_complete)
 
     @with_argparser(download_nucleus_parser)
     @with_category(CMD_CAT_DOWNLOAD)
@@ -357,6 +374,7 @@ class App(cmd2.Cmd):
         fid = download_nucleus_args.fid
         sa = download_nucleus_args.sa
         length = download_nucleus_args.length
+        path = download_nucleus_args.path
 
         if not self.nucleus_driver.connection.get_connection_status():
             self.nucleus_driver.messages.write_message('Nucleus not connected')
@@ -371,7 +389,7 @@ class App(cmd2.Cmd):
         if length is not None:
             length = int(length)
 
-        status = self.nucleus_driver.download_nucleus_data(fid=fid, sa=sa, length=length)
+        status = self.nucleus_driver.download_nucleus_data(fid=fid, sa=sa, length=length, path=path)
 
         if status:
             self.nucleus_driver.messages.write_message('Successfully downloaded data')
